.. LWA Software Library documentation master file, created by
   sphinx-quickstart on Wed Dec  1 16:06:23 2010.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

LWA Software Library Documentation
==================================
This package contains a collection of tools for reading, format shifting, 
and analyzing LWA data.  It also contains the majority of the lwa_user
library developed by NRL.

Contents
========

Installation
------------
.. toctree::
   :maxdepth: 2

   install
   rnotes

   lwa_user

General Utilities
-----------------
.. toctree::
   :maxdepth: 2

   consts
   astro
   kurtosis
   dedispersion
   catalog
   transform
   mathutils
   robust
   paths
   busy
   color
   progress

LWA-Specific Utilites
---------------------
.. toctree::
   :maxdepth: 2

   observations

   station
   sdf
   readers
   writers

   spectra

   correlator

   imaging

   beamformer

   fakedata

Miscellaneous
-------------
.. toctree::
   :maxdepth: 2

   misc

   genindex
   modindex
   search

Included Scripts
----------------
.. toctree::
   :maxdepth: 2

   scripts

Tutorials
=========
* `General LSL Routines <http://nbviewer.ipython.org/url/fornax.phys.unm.edu/lwa/subversion/trunk/lsl/doc/notebooks/LSL%20General%20Tutorial.ipynb>`_
* `Building SDFs Programmatically <http://nbviewer.ipython.org/url/fornax.phys.unm.edu/lwa/subversion/trunk/lsl/doc/notebooks/LSL%20SDF%20Generation.ipynb>`_
* `Observation Metadata <http://nbviewer.ipython.org/url/fornax.phys.unm.edu/lwa/subversion/trunk/lsl/doc/notebooks/LSL%20MCS%20Metadata%20Tutorial.ipynb>`_
* `Working with TBW/TBN Data <http://nbviewer.ipython.org/url/fornax.phys.unm.edu/lwa/subversion/trunk/lsl/doc/notebooks/LSL%20TBW%20%26%20TBN%20Tutorial.ipynb>`_
* `Working with DRX Data <http://nbviewer.ipython.org/url/fornax.phys.unm.edu/lwa/subversion/trunk/lsl/doc/notebooks/LSL%20DRX%20Tutorial.ipynb>`_

Advanced
========

.. toctree::
   :maxdepth: 2

   c-extensions

Indices and Tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

